@@ -1,4 +1,5 @@
 import collections
+import copy
 import itertools
 from typing import (
     Any,
@@ -79,6 +80,8 @@ class Recipe(Generic[M]):
                     mapping[k] = v.recipe.prepare(_using=_using, **recipe_attrs)
             elif isinstance(v, related):
                 mapping[k] = v.make
+            elif isinstance(v, collections.abc.Container):
+                mapping[k] = copy.deepcopy(v)
 
         mapping.update(new_attrs)
         mapping.update(rel_fields_attrs)
@@ -164,9 +167,11 @@ class Recipe(Generic[M]):
         **attrs: Any,
     ) -> Union[M, List[M]]:
         defaults = {
-            "_quantity": _quantity,
             "_save_related": _save_related,
         }
+        if _quantity is not None:
+            defaults["_quantity"] = _quantity  # type: ignore[assignment]
+
         defaults.update(attrs)
         return baker.prepare(
             self._model, _using=_using, **self._mapping(_using, defaults)
